==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/Matrix.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice minOccurs="0">
 *         &lt;group ref="{http://www.dmg.org/PMML-4_1}NUM-ARRAY" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}MatCell" maxOccurs="unbounded"/>
 *       &lt;/choice>
 *       &lt;attribute name="kind" default="any">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;enumeration value="diagonal"/>
 *             &lt;enumeration value="symmetric"/>
 *             &lt;enumeration value="any"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *       &lt;attribute name="nbRows" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="nbCols" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="diagDefault" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *       &lt;attribute name="offDiagDefault" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "numarrays",
    "matCells"
})
@XmlRootElement(name = "Matrix")
public class Matrix
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Array")
    protected List<ArrayType> numarrays;
    @XmlElement(name = "MatCell")
    protected List<MatCell> matCells;
    @XmlAttribute(name = "kind")
    protected Matrix.Kind kind;
    @XmlAttribute(name = "nbRows")
    protected BigInteger nbRows;
    @XmlAttribute(name = "nbCols")
    protected BigInteger nbCols;
    @XmlAttribute(name = "diagDefault")
    protected Double diagDefault;
    @XmlAttribute(name = "offDiagDefault")
    protected Double offDiagDefault;

    /**
     * Gets the value of the numarraYs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the numarraYs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNUMARRAYs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ArrayType }
     * 
     * 
     */
    public List<ArrayType> getNUMARRAYs() {
        if (numarrays == null) {
            numarrays = new ArrayList<ArrayType>();
        }
        return this.numarrays;
    }

    /**
     * Gets the value of the matCells property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the matCells property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMatCells().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MatCell }
     * 
     * 
     */
    public List<MatCell> getMatCells() {
        if (matCells == null) {
            matCells = new ArrayList<MatCell>();
        }
        return this.matCells;
    }

    /**
     * Gets the value of the kind property.
     * 
     * @return
     *     possible object is
     *     {@link Matrix.Kind }
     *     
     */
    public Matrix.Kind getKind() {
        if (kind == null) {
            return Matrix.Kind.ANY;
        } else {
            return kind;
        }
    }

    /**
     * Sets the value of the kind property.
     * 
     * @param value
     *     allowed object is
     *     {@link Matrix.Kind }
     *     
     */
    public void setKind(Matrix.Kind value) {
        this.kind = value;
    }

    /**
     * Gets the value of the nbRows property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNbRows() {
        return nbRows;
    }

    /**
     * Sets the value of the nbRows property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNbRows(BigInteger value) {
        this.nbRows = value;
    }

    /**
     * Gets the value of the nbCols property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNbCols() {
        return nbCols;
    }

    /**
     * Sets the value of the nbCols property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNbCols(BigInteger value) {
        this.nbCols = value;
    }

    /**
     * Gets the value of the diagDefault property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getDiagDefault() {
        return diagDefault;
    }

    /**
     * Sets the value of the diagDefault property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setDiagDefault(Double value) {
        this.diagDefault = value;
    }

    /**
     * Gets the value of the offDiagDefault property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getOffDiagDefault() {
        return offDiagDefault;
    }

    /**
     * Sets the value of the offDiagDefault property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setOffDiagDefault(Double value) {
        this.offDiagDefault = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof Matrix)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final Matrix that = ((Matrix) object);
        {
            List<ArrayType> lhsNUMARRAYs;
            lhsNUMARRAYs = (((this.numarrays!= null)&&(!this.numarrays.isEmpty()))?this.getNUMARRAYs():null);
            List<ArrayType> rhsNUMARRAYs;
            rhsNUMARRAYs = (((that.numarrays!= null)&&(!that.numarrays.isEmpty()))?that.getNUMARRAYs():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numarrays", lhsNUMARRAYs), LocatorUtils.property(thatLocator, "numarrays", rhsNUMARRAYs), lhsNUMARRAYs, rhsNUMARRAYs)) {
                return false;
            }
        }
        {
            List<MatCell> lhsMatCells;
            lhsMatCells = (((this.matCells!= null)&&(!this.matCells.isEmpty()))?this.getMatCells():null);
            List<MatCell> rhsMatCells;
            rhsMatCells = (((that.matCells!= null)&&(!that.matCells.isEmpty()))?that.getMatCells():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "matCells", lhsMatCells), LocatorUtils.property(thatLocator, "matCells", rhsMatCells), lhsMatCells, rhsMatCells)) {
                return false;
            }
        }
        {
            Matrix.Kind lhsKind;
            lhsKind = this.getKind();
            Matrix.Kind rhsKind;
            rhsKind = that.getKind();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "kind", lhsKind), LocatorUtils.property(thatLocator, "kind", rhsKind), lhsKind, rhsKind)) {
                return false;
            }
        }
        {
            BigInteger lhsNbRows;
            lhsNbRows = this.getNbRows();
            BigInteger rhsNbRows;
            rhsNbRows = that.getNbRows();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "nbRows", lhsNbRows), LocatorUtils.property(thatLocator, "nbRows", rhsNbRows), lhsNbRows, rhsNbRows)) {
                return false;
            }
        }
        {
            BigInteger lhsNbCols;
            lhsNbCols = this.getNbCols();
            BigInteger rhsNbCols;
            rhsNbCols = that.getNbCols();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "nbCols", lhsNbCols), LocatorUtils.property(thatLocator, "nbCols", rhsNbCols), lhsNbCols, rhsNbCols)) {
                return false;
            }
        }
        {
            Double lhsDiagDefault;
            lhsDiagDefault = this.getDiagDefault();
            Double rhsDiagDefault;
            rhsDiagDefault = that.getDiagDefault();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "diagDefault", lhsDiagDefault), LocatorUtils.property(thatLocator, "diagDefault", rhsDiagDefault), lhsDiagDefault, rhsDiagDefault)) {
                return false;
            }
        }
        {
            Double lhsOffDiagDefault;
            lhsOffDiagDefault = this.getOffDiagDefault();
            Double rhsOffDiagDefault;
            rhsOffDiagDefault = that.getOffDiagDefault();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "offDiagDefault", lhsOffDiagDefault), LocatorUtils.property(thatLocator, "offDiagDefault", rhsOffDiagDefault), lhsOffDiagDefault, rhsOffDiagDefault)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<ArrayType> theNUMARRAYs;
            theNUMARRAYs = (((this.numarrays!= null)&&(!this.numarrays.isEmpty()))?this.getNUMARRAYs():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numarrays", theNUMARRAYs), currentHashCode, theNUMARRAYs);
        }
        {
            List<MatCell> theMatCells;
            theMatCells = (((this.matCells!= null)&&(!this.matCells.isEmpty()))?this.getMatCells():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "matCells", theMatCells), currentHashCode, theMatCells);
        }
        {
            Matrix.Kind theKind;
            theKind = this.getKind();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "kind", theKind), currentHashCode, theKind);
        }
        {
            BigInteger theNbRows;
            theNbRows = this.getNbRows();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "nbRows", theNbRows), currentHashCode, theNbRows);
        }
        {
            BigInteger theNbCols;
            theNbCols = this.getNbCols();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "nbCols", theNbCols), currentHashCode, theNbCols);
        }
        {
            Double theDiagDefault;
            theDiagDefault = this.getDiagDefault();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "diagDefault", theDiagDefault), currentHashCode, theDiagDefault);
        }
        {
            Double theOffDiagDefault;
            theOffDiagDefault = this.getOffDiagDefault();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "offDiagDefault", theOffDiagDefault), currentHashCode, theOffDiagDefault);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }


    /**
     * <p>Java class for null.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * <p>
     * <pre>
     * &lt;simpleType>
     *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
     *     &lt;enumeration value="diagonal"/>
     *     &lt;enumeration value="symmetric"/>
     *     &lt;enumeration value="any"/>
     *   &lt;/restriction>
     * &lt;/simpleType>
     * </pre>
     * 
     */
    @XmlType(name = "")
    @XmlEnum
    public enum Kind {

        @XmlEnumValue("diagonal")
        DIAGONAL("diagonal"),
        @XmlEnumValue("symmetric")
        SYMMETRIC("symmetric"),
        @XmlEnumValue("any")
        ANY("any");
        private final String value;

        Kind(String v) {
            value = v;
        }

        public String value() {
            return value;
        }

        public static Matrix.Kind fromValue(String v) {
            for (Matrix.Kind c: Matrix.Kind.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

    }

}

==> pmml-model-1.0.3-sources.jar: org/dmg/pmml/Matrix.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice minOccurs="0">
 *         &lt;group ref="{http://www.dmg.org/PMML-4_1}NUM-ARRAY" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}MatCell" maxOccurs="unbounded"/>
 *       &lt;/choice>
 *       &lt;attribute name="kind" default="any">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;enumeration value="diagonal"/>
 *             &lt;enumeration value="symmetric"/>
 *             &lt;enumeration value="any"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *       &lt;attribute name="nbRows" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="nbCols" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="diagDefault" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *       &lt;attribute name="offDiagDefault" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "numarrays",
    "matCells"
})
@XmlRootElement(name = "Matrix")
public class Matrix
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Array")
    protected List<ArrayType> numarrays;
    @XmlElement(name = "MatCell")
    protected List<MatCell> matCells;
    @XmlAttribute(name = "kind")
    protected Matrix.Kind kind;
    @XmlAttribute(name = "nbRows")
    protected BigInteger nbRows;
    @XmlAttribute(name = "nbCols")
    protected BigInteger nbCols;
    @XmlAttribute(name = "diagDefault")
    protected Double diagDefault;
    @XmlAttribute(name = "offDiagDefault")
    protected Double offDiagDefault;

    /**
     * Gets the value of the numarraYs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the numarraYs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNUMARRAYs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ArrayType }
     * 
     * 
     */
    public List<ArrayType> getNUMARRAYs() {
        if (numarrays == null) {
            numarrays = new ArrayList<ArrayType>();
        }
        return this.numarrays;
    }

    /**
     * Gets the value of the matCells property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the matCells property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMatCells().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MatCell }
     * 
     * 
     */
    public List<MatCell> getMatCells() {
        if (matCells == null) {
            matCells = new ArrayList<MatCell>();
        }
        return this.matCells;
    }

    /**
     * Gets the value of the kind property.
     * 
     * @return
     *     possible object is
     *     {@link Matrix.Kind }
     *     
     */
    public Matrix.Kind getKind() {
        if (kind == null) {
            return Matrix.Kind.ANY;
        } else {
            return kind;
        }
    }

    /**
     * Sets the value of the kind property.
     * 
     * @param value
     *     allowed object is
     *     {@link Matrix.Kind }
     *     
     */
    public void setKind(Matrix.Kind value) {
        this.kind = value;
    }

    /**
     * Gets the value of the nbRows property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNbRows() {
        return nbRows;
    }

    /**
     * Sets the value of the nbRows property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNbRows(BigInteger value) {
        this.nbRows = value;
    }

    /**
     * Gets the value of the nbCols property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNbCols() {
        return nbCols;
    }

    /**
     * Sets the value of the nbCols property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNbCols(BigInteger value) {
        this.nbCols = value;
    }

    /**
     * Gets the value of the diagDefault property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getDiagDefault() {
        return diagDefault;
    }

    /**
     * Sets the value of the diagDefault property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setDiagDefault(Double value) {
        this.diagDefault = value;
    }

    /**
     * Gets the value of the offDiagDefault property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getOffDiagDefault() {
        return offDiagDefault;
    }

    /**
     * Sets the value of the offDiagDefault property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setOffDiagDefault(Double value) {
        this.offDiagDefault = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof Matrix)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final Matrix that = ((Matrix) object);
        {
            List<ArrayType> lhsNUMARRAYs;
            lhsNUMARRAYs = (((this.numarrays!= null)&&(!this.numarrays.isEmpty()))?this.getNUMARRAYs():null);
            List<ArrayType> rhsNUMARRAYs;
            rhsNUMARRAYs = (((that.numarrays!= null)&&(!that.numarrays.isEmpty()))?that.getNUMARRAYs():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numarrays", lhsNUMARRAYs), LocatorUtils.property(thatLocator, "numarrays", rhsNUMARRAYs), lhsNUMARRAYs, rhsNUMARRAYs)) {
                return false;
            }
        }
        {
            List<MatCell> lhsMatCells;
            lhsMatCells = (((this.matCells!= null)&&(!this.matCells.isEmpty()))?this.getMatCells():null);
            List<MatCell> rhsMatCells;
            rhsMatCells = (((that.matCells!= null)&&(!that.matCells.isEmpty()))?that.getMatCells():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "matCells", lhsMatCells), LocatorUtils.property(thatLocator, "matCells", rhsMatCells), lhsMatCells, rhsMatCells)) {
                return false;
            }
        }
        {
            Matrix.Kind lhsKind;
            lhsKind = this.getKind();
            Matrix.Kind rhsKind;
            rhsKind = that.getKind();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "kind", lhsKind), LocatorUtils.property(thatLocator, "kind", rhsKind), lhsKind, rhsKind)) {
                return false;
            }
        }
        {
            BigInteger lhsNbRows;
            lhsNbRows = this.getNbRows();
            BigInteger rhsNbRows;
            rhsNbRows = that.getNbRows();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "nbRows", lhsNbRows), LocatorUtils.property(thatLocator, "nbRows", rhsNbRows), lhsNbRows, rhsNbRows)) {
                return false;
            }
        }
        {
            BigInteger lhsNbCols;
            lhsNbCols = this.getNbCols();
            BigInteger rhsNbCols;
            rhsNbCols = that.getNbCols();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "nbCols", lhsNbCols), LocatorUtils.property(thatLocator, "nbCols", rhsNbCols), lhsNbCols, rhsNbCols)) {
                return false;
            }
        }
        {
            Double lhsDiagDefault;
            lhsDiagDefault = this.getDiagDefault();
            Double rhsDiagDefault;
            rhsDiagDefault = that.getDiagDefault();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "diagDefault", lhsDiagDefault), LocatorUtils.property(thatLocator, "diagDefault", rhsDiagDefault), lhsDiagDefault, rhsDiagDefault)) {
                return false;
            }
        }
        {
            Double lhsOffDiagDefault;
            lhsOffDiagDefault = this.getOffDiagDefault();
            Double rhsOffDiagDefault;
            rhsOffDiagDefault = that.getOffDiagDefault();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "offDiagDefault", lhsOffDiagDefault), LocatorUtils.property(thatLocator, "offDiagDefault", rhsOffDiagDefault), lhsOffDiagDefault, rhsOffDiagDefault)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<ArrayType> theNUMARRAYs;
            theNUMARRAYs = (((this.numarrays!= null)&&(!this.numarrays.isEmpty()))?this.getNUMARRAYs():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numarrays", theNUMARRAYs), currentHashCode, theNUMARRAYs);
        }
        {
            List<MatCell> theMatCells;
            theMatCells = (((this.matCells!= null)&&(!this.matCells.isEmpty()))?this.getMatCells():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "matCells", theMatCells), currentHashCode, theMatCells);
        }
        {
            Matrix.Kind theKind;
            theKind = this.getKind();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "kind", theKind), currentHashCode, theKind);
        }
        {
            BigInteger theNbRows;
            theNbRows = this.getNbRows();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "nbRows", theNbRows), currentHashCode, theNbRows);
        }
        {
            BigInteger theNbCols;
            theNbCols = this.getNbCols();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "nbCols", theNbCols), currentHashCode, theNbCols);
        }
        {
            Double theDiagDefault;
            theDiagDefault = this.getDiagDefault();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "diagDefault", theDiagDefault), currentHashCode, theDiagDefault);
        }
        {
            Double theOffDiagDefault;
            theOffDiagDefault = this.getOffDiagDefault();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "offDiagDefault", theOffDiagDefault), currentHashCode, theOffDiagDefault);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<ArrayType> theNUMARRAYs;
            theNUMARRAYs = (((this.numarrays!= null)&&(!this.numarrays.isEmpty()))?this.getNUMARRAYs():null);
            strategy.appendField(locator, this, "numarrays", buffer, theNUMARRAYs);
        }
        {
            List<MatCell> theMatCells;
            theMatCells = (((this.matCells!= null)&&(!this.matCells.isEmpty()))?this.getMatCells():null);
            strategy.appendField(locator, this, "matCells", buffer, theMatCells);
        }
        {
            Matrix.Kind theKind;
            theKind = this.getKind();
            strategy.appendField(locator, this, "kind", buffer, theKind);
        }
        {
            BigInteger theNbRows;
            theNbRows = this.getNbRows();
            strategy.appendField(locator, this, "nbRows", buffer, theNbRows);
        }
        {
            BigInteger theNbCols;
            theNbCols = this.getNbCols();
            strategy.appendField(locator, this, "nbCols", buffer, theNbCols);
        }
        {
            Double theDiagDefault;
            theDiagDefault = this.getDiagDefault();
            strategy.appendField(locator, this, "diagDefault", buffer, theDiagDefault);
        }
        {
            Double theOffDiagDefault;
            theOffDiagDefault = this.getOffDiagDefault();
            strategy.appendField(locator, this, "offDiagDefault", buffer, theOffDiagDefault);
        }
        return buffer;
    }


    /**
     * <p>Java class for null.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * <p>
     * <pre>
     * &lt;simpleType>
     *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
     *     &lt;enumeration value="diagonal"/>
     *     &lt;enumeration value="symmetric"/>
     *     &lt;enumeration value="any"/>
     *   &lt;/restriction>
     * &lt;/simpleType>
     * </pre>
     * 
     */
    @XmlType(name = "")
    @XmlEnum
    public enum Kind {

        @XmlEnumValue("diagonal")
        DIAGONAL("diagonal"),
        @XmlEnumValue("symmetric")
        SYMMETRIC("symmetric"),
        @XmlEnumValue("any")
        ANY("any");
        private final String value;

        Kind(String v) {
            value = v;
        }

        public String value() {
            return value;
        }

        public static Matrix.Kind fromValue(String v) {
            for (Matrix.Kind c: Matrix.Kind.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

    }

}
